@@ -2,7 +2,7 @@
 from django.template import RequestContext
 from django.template.loader import render_to_string
 
-from mailer import send_html_mail
+import mailer
 
 from .utils import html_to_plain_text
 
@@ -32,5 +32,5 @@ def send_email(request, extra_context, subject_template, body_template,
     subject = ''.join(subject.splitlines())
     message_html = render_to_string(body_template, context)
     message_plaintext = html_to_plain_text(message_html)
-    send_html_mail(subject, message_plaintext, message_html, from_email,
-                   recipients, priority=priority)
+    mailer.send_html_mail(subject, message_plaintext, message_html, from_email,
+                          recipients, priority=priority)
